==> tellico-trinity_3.5.13.2.orig.tar.xz: tellico-trinity-3.5.13.2/src/fetch/srufetcher.h <==
/***************************************************************************
    copyright            : (C) 2003-2006 by Robby Stephenson
    email                : robby@periapsis.org
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of version 2 of the GNU General Public License as  *
 *   published by the Free Software Foundation;                            *
 *                                                                         *
 ***************************************************************************/

#ifndef TELLICO_SRUFETCHER_H
#define TELLICO_SRUFETCHER_H

namespace Tellico {
  class XSLTHandler;
  namespace GUI {
    class LineEdit;
    class ComboBox;
  }
}

class KIntSpinBox;
class KComboBox;
namespace KIO {
  class Job;
}

#include "fetcher.h"
#include "configwidget.h"
#include "../datavectors.h"

#include <tqcstring.h> // for TQByteArray
#include <tqguardedptr.h>

namespace Tellico {
  namespace Fetch {

class SRUConfigWidget;

/**
 * A fetcher for SRU servers.
 * Right now, only MODS is supported.
 *
 * @author Robby Stephenson
 */
class SRUFetcher : public Fetcher {
Q_OBJECT
  TQ_OBJECT

friend class SRUConfigWidget;

public:
  /**
   */
  SRUFetcher(TQObject* parent, const char* name = 0);
  SRUFetcher(const TQString& name, const TQString& host, uint port, const TQString& dbname,
             TQObject* parent);
  /**
   */
  virtual ~SRUFetcher();

  /**
   */
  virtual TQString source() const;
  virtual bool isSearching() const { return m_started; }
  virtual void search(FetchKey key, const TQString& value);
  // only search title, person, isbn, or keyword. No Raw for now.
  virtual bool canSearch(FetchKey k) const { return k == Title || k == Person || k == ISBN || k == Keyword || k == LCCN; }
  virtual void stop();
  virtual Data::EntryPtr fetchEntry(uint uid);
  virtual Type type() const { return SRU; }
  virtual bool canFetch(int type) const;
  virtual void readConfigHook(const KConfigGroup& config);

  virtual void updateEntry(Data::EntryPtr entry);

  static StringMap customFields();

  virtual ConfigWidget* configWidget(TQWidget* parent) const;

  static TQString defaultName();

  static Fetcher::Ptr libraryOfCongress(TQObject* parent);

private slots:
  void slotData(KIO::Job* job, const TQByteArray& data);
  void slotComplete(KIO::Job* job);

private:
  bool initMARCXMLHandler();
  bool initMODSHandler();

  TQString m_host;
  uint m_port;
  TQString m_path;
  TQString m_format;

  TQByteArray m_data;
  TQMap<int, Data::EntryPtr> m_entries;
  TQGuardedPtr<KIO::Job> m_job;
  XSLTHandler* m_MARCXMLHandler;
  XSLTHandler* m_MODSHandler;
  bool m_started;
  TQStringList m_fields;
};

class SRUConfigWidget : public ConfigWidget {
Q_OBJECT
  TQ_OBJECT

friend class SRUFetcher;

public:
  SRUConfigWidget(TQWidget* parent_, const SRUFetcher* fetcher = 0);
  virtual void saveConfig(KConfigGroup& config);
  virtual TQString preferredName() const;

private slots:
  void slotCheckHost();

private:
  GUI::LineEdit* m_hostEdit;
  KIntSpinBox* m_portSpinBox;
  GUI::LineEdit* m_pathEdit;
  GUI::ComboBox* m_formatCombo;
};

  } // end namespace
} // end namespace
#endif

==> tellico-trinity-14.0.13.tar.xz: tellico-trinity-14.0.13/src/fetch/srufetcher.h <==
/***************************************************************************
    copyright            : (C) 2003-2006 by Robby Stephenson
    email                : robby@periapsis.org
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of version 2 of the GNU General Public License as  *
 *   published by the Free Software Foundation;                            *
 *                                                                         *
 ***************************************************************************/

#ifndef TELLICO_SRUFETCHER_H
#define TELLICO_SRUFETCHER_H

namespace Tellico {
  class XSLTHandler;
  namespace GUI {
    class LineEdit;
    class ComboBox;
  }
}

class KIntSpinBox;
class KComboBox;
namespace TDEIO {
  class Job;
}

#include "fetcher.h"
#include "configwidget.h"
#include "../datavectors.h"

#include <tqcstring.h> // for TQByteArray
#include <tqguardedptr.h>

namespace Tellico {
  namespace Fetch {

class SRUConfigWidget;

/**
 * A fetcher for SRU servers.
 * Right now, only MODS is supported.
 *
 * @author Robby Stephenson
 */
class SRUFetcher : public Fetcher {
Q_OBJECT
  

friend class SRUConfigWidget;

public:
  /**
   */
  SRUFetcher(TQObject* parent, const char* name = 0);
  SRUFetcher(const TQString& name, const TQString& host, uint port, const TQString& dbname,
             TQObject* parent);
  /**
   */
  virtual ~SRUFetcher();

  /**
   */
  virtual TQString source() const;
  virtual bool isSearching() const { return m_started; }
  virtual void search(FetchKey key, const TQString& value);
  // only search title, person, isbn, or keyword. No Raw for now.
  virtual bool canSearch(FetchKey k) const { return k == Title || k == Person || k == ISBN || k == Keyword || k == LCCN; }
  virtual void stop();
  virtual Data::EntryPtr fetchEntry(uint uid);
  virtual Type type() const { return SRU; }
  virtual bool canFetch(int type) const;
  virtual void readConfigHook(const TDEConfigGroup& config);

  virtual void updateEntry(Data::EntryPtr entry);

  static StringMap customFields();

  virtual ConfigWidget* configWidget(TQWidget* parent) const;

  static TQString defaultName();

  static Fetcher::Ptr libraryOfCongress(TQObject* parent);

private slots:
  void slotData(TDEIO::Job* job, const TQByteArray& data);
  void slotComplete(TDEIO::Job* job);

private:
  bool initMARCXMLHandler();
  bool initMODSHandler();

  TQString m_host;
  uint m_port;
  TQString m_path;
  TQString m_format;

  TQByteArray m_data;
  TQMap<int, Data::EntryPtr> m_entries;
  TQGuardedPtr<TDEIO::Job> m_job;
  XSLTHandler* m_MARCXMLHandler;
  XSLTHandler* m_MODSHandler;
  bool m_started;
  TQStringList m_fields;
};

class SRUConfigWidget : public ConfigWidget {
Q_OBJECT
  

friend class SRUFetcher;

public:
  SRUConfigWidget(TQWidget* parent_, const SRUFetcher* fetcher = 0);
  virtual void saveConfig(TDEConfigGroup& config);
  virtual TQString preferredName() const;

private slots:
  void slotCheckHost();

private:
  GUI::LineEdit* m_hostEdit;
  KIntSpinBox* m_portSpinBox;
  GUI::LineEdit* m_pathEdit;
  GUI::ComboBox* m_formatCombo;
};

  } // end namespace
} // end namespace
#endif
